@@ -25,7 +25,7 @@ Copyright 2003-2004 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: combroyden2.c 886 2007-08-18 03:09:50Z beerli $
+$Id: combroyden2.c 1189 2008-03-10 19:58:39Z beerli $
  
 -------------------------------------------------------*/
 
@@ -269,11 +269,24 @@ estimateParameter (long rep, long G, world_fmt * world, option_fmt * options,
                      "           Maximization cycles needed: %li\n           Norm of first derivatives:  %f\n", trials, nr->normd);
         }
     }
-    if (kind == MULTILOCUS && world->options->plotnow && world->loci > 1)
+#ifdef MPI
+    if (myID==MASTER  && world->options->plotnow)
+#else
+      if (kind == MULTILOCUS && world->options->plotnow && world->loci > 1)
+#endif
     {
-        if (((world->options->replicate && repkind != SINGLECHAIN) ||
+      if (((world->options->replicate && repkind != SINGLECHAIN) ||
                 (!world->options->replicate && repkind == SINGLECHAIN)) && (world->numpop > 1))
-            create_plot (world, world->plane[world->loci], nr, world->loci, MULTILOCUSPLOT); 
+#ifdef MPI
+	{
+	  if(world->loci==1)
+	    create_plot (world, world->plane[0], nr, world->loci, MULTILOCUSPLOT); 
+	  else
+	    create_plot (world, world->plane[world->loci], nr, world->loci, MULTILOCUSPLOT); 
+	}
+#else
+      create_plot (world, world->plane[world->loci], nr, world->loci, MULTILOCUSPLOT); 
+#endif
     }
 #ifdef LONGSUM
     memcpy (world->flucrates, param+nr->numpop2+
