@@ -22,7 +22,7 @@ Copyright 2003-2007 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: data.c 1220 2008-03-28 01:36:29Z beerli $
+$Id: data.c 1314 2008-07-05 13:47:13Z beerli $
  
 -------------------------------------------------------*/
 /*! \file data.c
@@ -945,6 +945,13 @@ read_hapmap (FILE * infile, data_fmt * data, option_fmt * options,
     for(locus=0;locus<data->loci;locus++)
       {
 	read_word(infile,input);
+	if(input[0]=='#')
+	  {
+	    fprintf(stdout,"%s\n",input);
+	    FGETS(input,LINESIZE,infile);
+	    locus--;
+	    continue;
+	  }
 	data->position[locus] = atol(input);
 	if(options->printdata)
 	  {
@@ -1389,19 +1396,25 @@ void print_spectra(world_fmt * world, option_fmt * options,data_fmt * data)
 	      thatallele = data->yy[pop][ind][locus][1];
 	      if(!strcmp(thisallele,thatallele))
 		{
-		     freq[pop][locus][found] += 2.0 ;
 		     if(!strchr(thisallele,'?'))
-			total[pop][locus] += 2.0 ;
+		       {
+			 freq[pop][locus][found] += 2.0 ;
+			 total[pop][locus] += 2.0 ;
+		       }
 		}
 	      else
 		{
-		  freq[pop][locus][found] += 1.0 ;
 		  if(!strchr(thisallele,'?'))
-		     total[pop][locus] += 1.0 ;
+		    {
+		      freq[pop][locus][found] += 1.0 ;
+		      total[pop][locus] += 1.0 ;
+		    }
 		  found = findAllele(data, thatallele, locus);
-		  freq[pop][locus][found] += 1.0 ;
 		  if(!strchr(thatallele,'?'))
-		    total[pop][locus] += 1.0 ;
+		    {
+		      freq[pop][locus][found] += 1.0 ;
+		      total[pop][locus] += 1.0 ;
+		    }
 		}
 	    }
 	}
@@ -1422,7 +1435,7 @@ void print_spectra(world_fmt * world, option_fmt * options,data_fmt * data)
   for (locus = 0; locus < data->loci; locus++)
     {
       memset(maxallelepop,'\0',sizeof(long)*data->numpop);
-      fprintf(outfile,"Locus %li\n", locus);
+      fprintf(outfile,"Locus %li\n", locus + 1);
       fprintf(outfile,"Allele  ");
       for (pop = 0; pop < data->numpop; pop++)
 	fprintf(outfile,"Pop%-2li  ",pop+1);
@@ -1654,6 +1667,8 @@ void
 addAllele (data_fmt * data, char s[], long locus, long *z)
 {
     long found = 0;
+    if(!strcmp("?",s))
+      return;
     while ((data->allele[locus][found++][0] != '\0')
             && (strcmp (s, data->allele[locus][found - 1])))
         ;
