@@ -10,6 +10,56 @@
 #include "sighandler.h"
 
 
+void read_from_bayesmdim_minimal_info(FILE *mdimfile, world_fmt *world,option_fmt *options, data_fmt *data)
+{
+  char *input;
+  long nrep;
+  long pop;
+  long tmp;
+  boolean done=FALSE;
+  boolean recordedusem=TRUE;
+  input = (char *) mycalloc(LINESIZE , sizeof(char));
+  while(done==FALSE && FGETS(input,LINESIZE,mdimfile) != EOF)
+    {
+      if(input[0] == '#' && strstr(input,"begin"))
+	{
+	  FGETS(input,LINESIZE,mdimfile);
+	  options->custm = myrealloc(options->custm, sizeof(char) * (strlen(input)+1));
+	  strcpy(options->custm,input+9);
+	  FGETS (input, LINESIZE, mdimfile);
+	  options->custm2 = myrealloc(options->custm2, sizeof(char) * (strlen(input)+1));
+	  strcpy(options->custm2,input+9);
+	  FGETS (input, 1024, mdimfile);
+	  sscanf (input+3, "%li %li %li %li %li %i", &world->loci, &world->numpop,
+		  &world->numpop2, &tmp, &options->replicatenum,&recordedusem);
+	  nrep = options->replicatenum;
+	  if (nrep == 0)
+	    nrep = 1;
+	  options->replicate = (boolean) tmp;
+	  if(options->usem != recordedusem)
+	    options->recordedusem = recordedusem;
+        data->popnames = (char **) mymalloc (sizeof (char *) * world->numpop);
+        for (pop = 0; pop < world->numpop; pop++)
+	  {
+            data->popnames[pop] = (char *) mycalloc (1, sizeof (char) * LINESIZE);
+	    FGETS (input, LINESIZE, mdimfile);
+	    sscanf (input+3, "%s", data->popnames[pop]);
+	  }
+	done=TRUE;
+	}
+    }
+  options->muloci = data->loci = world->loci;
+  data->skiploci =
+    (boolean *) myrealloc (data->skiploci,
+			   sizeof (boolean) * (data->loci + 1));
+  memset (data->skiploci, 0, sizeof (boolean) * (data->loci + 1));
+  data->numpop = world->numpop;
+  myfree(input);
+}
+			    
+      
+void read_bayes_fromfile(FILE *mdimfile, world_fmt *world,option_fmt *options);
+
 long get_fullbinsum(MYREAL *lowerbound, MYREAL *upperbound, world_fmt *world, option_fmt *options, long locus)
 {
   long temp=0;
@@ -36,8 +86,6 @@ long get_fullbinsum(MYREAL *lowerbound, MYREAL *upperbound, world_fmt *world, op
 }
 
 
-void read_bayes_fromfile(FILE *mdimfile, world_fmt *world,option_fmt *options);
-
 ///
 /// read bayesallfile from disk and creates all the needed parts to 
 /// recreate the output and pdf output
@@ -51,9 +99,14 @@ void read_bayes_fromfile(FILE *mdimfile, world_fmt *world,option_fmt *options)
   //  char *input;
   long step;
   long locus;
+  long numpop = world->numpop;
+  long numpop2 = world->numpop2;
+  long frompop;
+  long topop;
   long replicate;
   long T ; // was world->treetimes->T, but this construct is freed, we do not need to
   // keep this values as it only used for the output into bayesallfile
+  MYREAL treelength;
   MYREAL post;
   MYREAL like;
   MYREAL probg;
@@ -71,21 +124,23 @@ void read_bayes_fromfile(FILE *mdimfile, world_fmt *world,option_fmt *options)
   //  long binwidth;
   long numbins = 0;
   long numbinsall = 0;
-  MYREAL m;
+  //MYREAL m;
   boolean *done;
+  boolean recordedusem = options->usem;
 
   done = (boolean *) mycalloc(world->loci, sizeof(boolean));
-  params = (MYREAL *) mycalloc(2+ world->numpop2 + world->bayes->mu, sizeof(MYREAL));
-  lowerbound = (MYREAL *) mycalloc(world->numpop2 + world->bayes->mu * world->loci, sizeof(MYREAL));
-  upperbound = (MYREAL *) mycalloc(world->numpop2 + world->bayes->mu * world->loci, sizeof(MYREAL));
+  // params can be replaced by a single value for param and rate
+  params = (MYREAL *) mycalloc(2+ numpop2 + world->bayes->mu, sizeof(MYREAL));
+  lowerbound = (MYREAL *) mycalloc(numpop2 + world->bayes->mu * world->loci, sizeof(MYREAL));
+  upperbound = (MYREAL *) mycalloc(numpop2 + world->bayes->mu * world->loci, sizeof(MYREAL));
   //delta = (MYREAL *) mycalloc(world->numpop2 + world->bayes->mu * world->loci, sizeof(MYREAL));
-  n = (long *) mycalloc(world->numpop2 + world->bayes->mu * world->loci, sizeof(long));
+  n = (long *) mycalloc(numpop2 + world->bayes->mu * world->loci, sizeof(long));
 #ifdef BFDEBUG
-  input = (char *) mycalloc((2+world->numpop2) * (world->bayes->mu+1) * 40 + (2 + world->options->heated_chains) * 40, sizeof(char));
+  input = (char *) mycalloc(SUPERLINESIZE, sizeof(char));
 #else
-  input = (char *) mycalloc((2+world->numpop2) * (world->bayes->mu+1) * 40 , sizeof(char));
+  input = (char *) mycalloc(SUPERLINESIZE, sizeof(char));
 #endif
-  while(FGETS(input,LINESIZE,mdimfile) != EOF)
+  while(FGETS(input,SUPERLINESIZE,mdimfile) != EOF)
     {
       // grab the commentlines
       while(input[0]=='#')
@@ -98,16 +153,17 @@ void read_bayes_fromfile(FILE *mdimfile, world_fmt *world,option_fmt *options)
 	  inptr = input;
 	  step       = atol(strsep(&inptr,"\t"));
 	  locus      = atol(strsep(&inptr,"\t"))-1;
+	  if(locus == -1)
+	    error("help");
 	  replicate  = atol(strsep(&inptr,"\t"))-1;
 	  post       = atof(strsep(&inptr,"\t"));
 	  like       = atof(strsep(&inptr,"\t"));
 	  probg      = atof( strsep(&inptr,"\t"));
 	  prior      = atof( strsep(&inptr,"\t"));
 	  T = atol(strsep(&inptr,"\t"))+1;
+	  treelength = atof(strsep(&inptr,"\t"));
 	  params[0] = post;
 	  params[1] = like;
-	  //	  if(fabs(like - world->likelihood[world->G])> SMALLEPSILON)
-	  //   world->likelihood[world->G++]=like;
 	  if(!done[locus])
 	    {
 
@@ -122,7 +178,7 @@ void read_bayes_fromfile(FILE *mdimfile, world_fmt *world,option_fmt *options)
 	    }
 	  hist = &bayes->histogram[locus];
 	  numbinsall = 0;
-	  for(j0=0;j0 <  world->numpop2; j0++)
+	  for(j0=0;j0 < numpop2; j0++)
 	    {
 	      if(bayes->map[j0][1] == INVALID)
 		continue;
@@ -132,44 +188,44 @@ void read_bayes_fromfile(FILE *mdimfile, world_fmt *world,option_fmt *options)
 		}
 	      if(j < j0)
 		{
-		  //params[j0+2] = params[j+2];
 		  continue;
 		}
 	      else
 		{
 		  params[j+2] =  atof(strsep(&inptr,"\t"));
-		  //mn = mn  + (xn - mn)/n
+		  if(j>=numpop && options->usem!=recordedusem)
+		    {
+		      m2mm(j, numpop,&frompop,&topop);
+		      if(recordedusem)// recorded bayesallfile was with M, new request is for 4Nm 
+			{
+			  params[j+2] *= params[topop+2];
+			}
+		      else //recorded bayesallfile was with xNm, new request is for M
+			{
+			  params[j+2] /= params[topop+2];
+			}
+		    }
 		  n[j] += 1;
 		  hist->means[j] += (params[j+2] - hist->means[j]) / n[j];
 		}
 	      numbinsall += hist->bins[j];
 	      numbins = numbinsall - hist->bins[j];
-
-	      //binwidth = hist->bins[j];
 	      bin = (long) ((params[j+2]-lowerbound[j]) / delta[j]);
 	      hist->minima[j0] = lowerbound[j];
 	      hist->maxima[j0] = upperbound[j];
-	      //	      m = bin * delta[j];
-	      //if(m < hist->minima[j0])
-	      //	hist->minima[j0] = m;
-	      //if(m > hist->maxima[j0])
-	      //		hist->maxima[j0] = m;
 	      hist->results[numbins + bin] += 1.;
 	    }
 	  if(bayes->mu)
 	    {
-	      //binwidth = hist->bins[j0];
 	      numbins = numbinsall;
 	      params[j0+2] = atof(strsep(&inptr,"\t"));
-	      n[j0] += 1;
-	      hist->means[j0] += (params[j0+2] - hist->means[j0]) / n[j0];
+	      n[j0+locus] += 1;
+	      hist->means[j0] += (params[j0+2] - hist->means[j0]) / n[j0+locus];
 	      bin = (long) ((params[j0+2]-lowerbound[j0]) / delta[j0]); 
-	      //m = bin * delta[j0];
-	      //if(m < hist->minima[j0])
-	      //	hist->minima[j0] = m;
-	      //if(m > hist->maxima[j0])
-	      //		hist->maxima[j0] = m;
+	      hist->minima[j0] = lowerbound[j0];
+	      hist->maxima[j0] = upperbound[j0];
 	      hist->results[numbins + bin] += 1.;
+
 	    }
 	}
     } 
