@@ -19,14 +19,14 @@
 *   beerli@scs.fsu.edu
 *
 *   Copyright 1997-2002 Peter Beerli and Joseph Felsenstein, Seattle WA\n
-*   Copyright 2003-2007 Peter Beerli, Tallahassee FL\n
+*   Copyright 2003-2008 Peter Beerli, Tallahassee FL\n
 *
 *   This software is distributed free of charge for non-commercial use
 *   and is copyrighted. Of course, I do not guarantee that the software
 *   works and am not responsible for any damage you may cause or have.
 *
 */
-/* $Id: main.c 1228 2008-04-02 12:47:16Z beerli $*/
+/* $Id: main.c 1309 2008-06-29 18:01:37Z beerli $*/
 
 #include "migration.h"
 #include "sighandler.h"
@@ -143,6 +143,7 @@ int page_counter;
 char pdf_pagetitle[LINESIZE+1];
 char pdf_time[LINESIZE+1];
 float page_height;
+float left_margin;
 float page_width;
 #endif
 
@@ -238,9 +239,8 @@ void
 print_heating_progress (world_fmt ** universe,
                         worldoption_fmt * options, long stepinc);
 
-long
-analyze_olddata (world_fmt * world, option_fmt * options,
-                 data_fmt * data, long *outfilepos);
+long analyze_olddata (world_fmt * world, option_fmt * options, data_fmt * data, long *outfilepos);
+boolean analyze_oldbayesdata(world_fmt *world, option_fmt *options, data_fmt *data, long *outfilepos);
 void print_theta0(FILE *file, world_fmt *world, long maxreplicate);
 void profile_tables (option_fmt * options, world_fmt * world, long *gmaxptr);
 
@@ -290,29 +290,29 @@ enum override_enum
 int
 main (int argc, char **argv)
 {
-  // for debug to stop at first statement of main() char c;
-  int usemenu = OVERRIDE_NO;
-    char type = 's';
-    data_fmt *data;
+  char      type       = 's';
+  int       usize      = 1;
+  int       usemenu    = OVERRIDE_NO;
+  long      locus;
+  long      Gmax       = 0;
+  long      outfilepos = 0;
+  data_fmt  *data;
+  boolean   restarted_bayes_bool=FALSE;
 #ifdef INTEGRATEDLIKE
-    long maxreplicate;
+  long      maxreplicate;
 #endif
-    int usize = 1;
-    long Gmax = 0;
-    long locus;
-    long outfilepos = 0;
-    option_fmt *options;
-    world_fmt **universe;
+  option_fmt *options;
+  world_fmt **universe;
 #ifdef MPI
-    int server;
+  int       server;
 #endif
 #ifdef HAVE_NICE
-    nice (10);			//nice value arbitrarily set to 10, 5 is still nice, 0 is standard
+  nice (10); //nice value arbitrarily set to 10, 5 is still nice, 0 is standard
 #endif
-    // puts(argv[0]);
-
-    //---------------------------------------------------------------------------------------------
-    // windows specific code for pretty printing
+  // puts(argv[0]);
+  
+  //---------------------------------------------------------------------------------------------
+  // windows specific code for pretty printing
 #ifdef PRETTY
 #ifdef WIN32
     set_haru_handler();
@@ -425,8 +425,8 @@ main (int argc, char **argv)
       {
 	if(options->bayes_infer)
 	  {
-	    // reanalyze old or borken bayesrun [not ready yet]
-	    // analyze_oldbayesdata(EARTH, options, data, &outfilepos);
+	    // reanalyze old or broken bayesrun [not ready yet]
+	    restarted_bayes_bool = analyze_oldbayesdata(EARTH, options, data, &outfilepos);
 	  }
 	else
 	  {
@@ -449,7 +449,8 @@ main (int argc, char **argv)
       {
 	// if bayes intermediate data recording is ON then reset the file
 	// for reading for printing and combining, else use the material still in RAM
-	reset_bayesmdimfile(EARTH, options);
+	if(!restarted_bayes_bool)
+	  reset_bayesmdimfile(EARTH, options);
       }
     else
       {
@@ -554,14 +555,14 @@ main (int argc, char **argv)
       {
 #endif
 	// print marginal likelihoods
-	if(EARTH->options->bayes_infer)
+	if(EARTH->options->bayes_infer && options->datatype!='g')
 	  {
 	    print_bayesfactor(EARTH->outfile, universe,options);
 	  }
 	
 	// printing of MCMC run characteristica
 	
-	if(EARTH->options->bayes_infer)
+	if(EARTH->options->bayes_infer  && options->datatype!='g')
 	  {
 	    fprintf(EARTH->outfile,"MCMC run characteristics\n");
 	    fprintf(EARTH->outfile,"========================\n\n");
@@ -584,7 +585,7 @@ main (int argc, char **argv)
 	
 	if(EARTH->options->progress)
 	  {
-	    if(EARTH->options->bayes_infer)
+	    if(EARTH->options->bayes_infer && options->datatype!='g')
 	      {
 		fprintf(stdout,"\nMCMC run characteristics: Autocorrelation and Effective sample size\n");
 		fprintf(stdout,"-------------------------------------------------------------------\n\n");
@@ -781,9 +782,6 @@ run_sampler (option_fmt * options, data_fmt * data, world_fmt ** universe,
   long i;
   long maxreplicate;
   long treefilepos;
-#ifdef PRETTY
-  float left_margin;
-#endif /*PRETTY*/
 #ifdef MPI
   //#ifdef MPIREPLICANT
   //    MPI_Status status;		// contains status used in MPI_Recv
@@ -869,15 +867,7 @@ run_sampler (option_fmt * options, data_fmt * data, world_fmt ** universe,
             print_data_summary (stdout, EARTH, options, data);
         /* print to outfile */
 #ifdef PRETTY
-        ////////////////////////////////////  
-        pdf_init();
-        // add first page
-        pdf_new_page(options->title);
-        pdf_master_title(options->title,  &page_height, &left_margin);
-        pdf_print_options(EARTH, options, data, &page_height, &left_margin);
-        pdf_print_data_summary(EARTH, options, data,  &page_height, &left_margin);
-        pdf_print_data (EARTH, options, data, &page_height, &left_margin);
-        ////////////////////////////////////  
+  pdf_master_init(EARTH, options, data);
 #endif 
         *outfilepos = print_title (EARTH, options);
         print_options (EARTH->outfile, EARTH, options, data);
@@ -889,7 +879,7 @@ run_sampler (option_fmt * options, data_fmt * data, world_fmt ** universe,
 	  {
 	    if(options->has_bayesmdimfile)
 	      print_bayes_mdimfileheader(EARTH->bayesmdimfile,
-					 options->bayesmdiminterval, EARTH);
+					 options->bayesmdiminterval, EARTH, data);
 	  }
     }
     if (options->lchains < 2 && options->replicatenum == 0)
@@ -932,6 +922,7 @@ run_sampler (option_fmt * options, data_fmt * data, world_fmt ** universe,
 #else /*MPI*/
     run_loci (universe, usize, options, data,
               &heating_pool, maxreplicate, &treefilepos, Gmax);
+
 #endif /*MPI*/
 #ifdef PTHREADS
     tpool_destroy (heating_pool, 1);
@@ -1230,9 +1221,6 @@ analyze_olddata (world_fmt * world,
     long locus;
 #else
     long listofthings[6];
-#endif
-#ifdef PRETTY
-    float left_margin;
 #endif
     long Gmax = 0;
     long pop;
@@ -1298,14 +1286,7 @@ analyze_olddata (world_fmt * world,
         print_options (stdout, world, options, data);
         print_options (world->outfile, world, options, data);
 #ifdef PRETTY
-        ////////////////////////////////////  
-        pdf_init();
-        // add first page
-        pdf_new_page(options->title);
-        pdf_master_title(options->title,  &page_height, &left_margin);
-        page_height -= 20; // option title should not straddle the line
-        pdf_print_options(world, options, data, &page_height, &left_margin);
-        ////////////////////////////////////        
+	pdf_master_init(world, options, data);
 #endif
         
 #ifdef MPI
@@ -1347,6 +1328,37 @@ analyze_olddata (world_fmt * world,
     return Gmax;
 } /*analyze_olddata()*/
 
+
+boolean analyze_oldbayesdata(world_fmt *world, option_fmt *options, data_fmt *data, long *outfilepos)
+{
+  long locus;
+  // read data from bayesfile
+  world->cold=TRUE;
+  // reads some minimal information form the header of the bayesallfile
+  // this only works with files written with migrate 2.5+
+  read_from_bayesmdim_minimal_info(world->bayesmdimfile, world, options, data);
+  read_geofile (data, options, world->numpop);
+  init_world (world, data, options);
+  set_meanmu(world,options);
+
+  read_bayes_fromfile(world->bayesmdimfile, world, options);
+#ifdef PRETTY
+  pdf_master_init(world, options, data);
+#endif
+  for(locus=0;locus<world->loci;locus++)
+    {
+      if(world->data->skiploci[locus])
+	continue;
+      if(world->bayes->histogram[locus].results == NULL)
+	{
+	  world->data->skiploci[locus] = TRUE;
+	  continue;
+	}
+      calc_hpd_credibility(world->bayes, locus, world->numpop2, world->numpop2 + world->bayes->mu);
+    }
+  return TRUE;
+}
+
 /// generate profile likelihood tables
 void
 profile_tables (option_fmt * options, world_fmt * world, long *gmaxptr)
@@ -1505,12 +1517,14 @@ setup_locus (long locus, world_fmt * world, option_fmt * options,
   first_smooth (world, locus);
   world->likelihood[0] = -MYREAL_MAX; //treelikelihood (world);
   world->allikemax = -MYREAL_MAX;	/* for best tree option */
+  world->treelen = 0.0;
+  calc_treelength (world->root->next->back, &world->treelen);
 #ifdef UEP
   if (options->uep)
     {
         world->treelen = 0.0;
         if (options->ueprate > 0.0)
-            calc_treelength (world->root->next->back, &world->treelen);
+	  calc_treelength (world->root->next->back, &world->treelen);
         //world->ueplikelihood = ueplikelihood(world);
         //world->likelihood[0] += world->ueplikelihood;
     }
@@ -1744,6 +1758,9 @@ run_locus (world_fmt ** universe, int usize, option_fmt * options,
   long i;
   long convergence_len = universe[0]->numpop2 + 3 * universe[0]->numpop;
   long replicate;
+  // DEBUG Hapmap stuff
+  if(EARTH->data->skiploci[locus])
+    return;
   if(options->bayes_infer)
     convergence_len = universe[0]->numpop2 + 1;
   memset(EARTH->convergence->chain_means,0,maxreplicate * convergence_len * sizeof(MYREAL));
@@ -1758,7 +1775,8 @@ run_locus (world_fmt ** universe, int usize, option_fmt * options,
 	  if(options->gelman)
 	    {
 	      chain_means(&EARTH->convergence->chain_means[replicate * convergence_len], EARTH);
-	      chain_s(EARTH->convergence->chain_s, EARTH->convergence->chain_means, EARTH, replicate);
+	      calc_chain_s(EARTH->convergence->chain_s, EARTH->convergence->chain_means, EARTH, 
+			   replicate);
 	      if (replicate > 0)
 		{
 		  convergence_check_bayes(EARTH, maxreplicate);
@@ -2263,9 +2281,11 @@ void print_bayesfactor(FILE *file, world_fmt **universe, option_fmt * options)
   MYREAL heat0 = 1.;
   MYREAL heat1 = 1.;
   MYREAL bfsum = 0.;
+#ifdef NEWVERSION
   MYREAL bfsum2 = 0.;
   MYREAL approxlsum = 0.;
   MYREAL intercept = 0.;
+#endif
   MYREAL hsum = 0.;
   MYREAL asum = 0.;
   MYREAL lsum;
@@ -2688,8 +2708,11 @@ void reset_bayesmdimfile(world_fmt *world, option_fmt *options)
       // save parameters in file and reload
       if(myID==MASTER)
 	{
-	  FClose(world->bayesmdimfile);
-	  openfile(&world->bayesmdimfile, options->bayesmdimfilename,"r+",NULL);
+	  fflush(world->bayesmdimfile);
+	  //	  FClose(world->bayesmdimfile);
+
+	  world->bayesmdimfile = freopen(options->bayesmdimfilename,"r+", world->bayesmdimfile);
+
 	  read_bayes_fromfile(world->bayesmdimfile,world, options);
 	  for(locus=0;locus<world->loci;locus++)
 	    {
@@ -2700,7 +2723,7 @@ void reset_bayesmdimfile(world_fmt *world, option_fmt *options)
 		  world->data->skiploci[locus] = TRUE;
 		  continue;
 		}
-	      calc_hpd_credibility(world->bayes, locus, world->numpop2 + world->bayes->mu);
+	      calc_hpd_credibility(world->bayes, locus, world->numpop2, world->numpop2 + world->bayes->mu);
 	    }
 	}
     }
