@@ -18,7 +18,7 @@ Copyright 2003-2006 Peter Beerli, Tallahassee FL
  and is copyrighted. Of course, we do not guarantee that the software
  works and are not responsible for any damage you may cause or have.
  
-$Id: mcmc1.c 1203 2008-03-20 02:02:56Z beerli $
+$Id: mcmc1.c 1291 2008-06-11 16:04:14Z beerli $
 -------------------------------------------------------*/
 /* \file mcmc1.c
 
@@ -47,6 +47,7 @@ Tree changer and acceptance rejection scheme
 #define WITH_MIGR_NODES 1
 
 extern int myID;
+extern MYREAL probg_treetimesX(world_fmt *world, vtlist *tl, long T);
 
 /* global for this file */
 proposal_fmt * gproposal;
@@ -128,7 +129,7 @@ tree_update (world_fmt * world, long g)
 #ifdef TESTING2
     static boolean have_proposal=FALSE;
 #endif
-    short show=0;
+    //short show=0;
     boolean coalesced;
     //  boolean test;
     char event;
@@ -298,10 +299,11 @@ tree_update (world_fmt * world, long g)
 	  {
 	    world->bayes->starttime = -world->bayes->starttime;
 	    world->bayes->stoptime = proposal->time;
+            world->treelen = 0.0;
+            calc_treelength (world->root->next->back, &world->treelen);
 	  }
 	//
 #ifdef UEP
-	
         world->likelihood[g] = treelikelihood (world);
         if (world->options->uep)
 	  {
@@ -513,7 +515,7 @@ set_new_proposal (proposal_fmt ** proposal, timelist_fmt * tl, world_fmt * world
     //    long mal = world->data->maxalleles[world->locus];
     long listsize = ((*tl).allocT + (*tl).T + 5);
     //    long sumtips = world->sumtips;
-
+    //could be used to calculate p(gn|go):    (*proposal)->nu = 0.;
     // allocate the scratchpad (contains a shadow of the tree)
     (*proposal) = gproposal;
     sumtips = (*proposal)->sumtips;
@@ -1656,11 +1658,12 @@ eventtime (proposal_fmt * proposal, long pop, vtlist * tentry, char *event)
     MYREAL  invrate = 1./ rate;
     MYREAL  mm         = proposal->mig0list[pop] * invrate ;
     //long    design0    = proposal->design0list[pop];
- 
+    //could be used to calculate p(gn|go): MYREAL nu;
     lines    = 2.0 * tentry->lineages[pop];
     denom    = mm + (lines * (1.0 / (proposal->param0[pop]*rate)));
     invdenom = 1.0 / denom;
-    interval = (-(LOG (UNIF_RANDUM ())) * invdenom) ;
+    interval = (-(LOG (/*nu = */UNIF_RANDUM ())) * invdenom) ;
+    //could be used to calculate p(gn|go): proposal->nu += nu; //adds the probabilities (=random numbers);
     //[overcautious]
     //if (interval < 0.0)
     //    error("interval time is negative");
