@@ -720,8 +720,7 @@ store_events (world_fmt * world, timelist_fmt * ltl, long np, long rep)
 	  {
 	    bb = &(world->mighistloci[world->locus]);
 	    
-	    if((*ltl).tl[0].eventnode->type != 't')// && (*ltl).tl[0].visited)
-	      //	if((*ltl).tl[0].eventnode->type!='t')
+	    if((*ltl).tl[0].eventnode->type != 't')
 	      {
 		calculate_event_values(bb->migeventbins, bb->migeventbinnum, bb->eventbinsize, 
 				       (*ltl).tl[0].age, 
@@ -745,7 +744,7 @@ store_events (world_fmt * world, timelist_fmt * ltl, long np, long rep)
 		t = (*ltl).tl[j].age - (*ltl).tl[j - 1].age;
 		//	    if((*ltl).tl[j].eventnode->type=='t')
 		//  continue;
-		if((*ltl).tl[j].eventnode->type != 't')// && (*ltl).tl[j].visited)
+		if((*ltl).tl[j].eventnode->type != 't')
 		  {
 		    // calculate event values
 		    calculate_event_values(bb->migeventbins, bb->migeventbinnum, bb->eventbinsize, 
