@@ -16,7 +16,7 @@
  
   Copyright 2002 Peter Beerli and Joseph Felsenstein, Seattle WA
   Copyright 2003 Peter Beerli, Tallahassee FL
-  $Id: migration.h 1156 2008-02-14 18:30:18Z beerli $
+  $Id: migration.h 1318 2008-07-10 19:49:13Z beerli $
   *----------------------------------------------------------------
 */
 /**
@@ -38,13 +38,17 @@ typedef long twin_fmt[2];
 typedef long quad_fmt[4];
 typedef MYREAL pair[2];
 typedef long longpair[2];
-typedef float tetra[5];
+typedef float tetra[9];
 typedef float duo[2];
 #ifdef ALTIVEC
 typedef FloatVec sitelike;
 #else
+#ifdef GAP
+typedef MYREAL sitelike[5];
+#else
 typedef MYREAL sitelike[4];
 #endif
+#endif
 //typedef MYREAL *sitelike;
 typedef sitelike *ratelike;
 typedef ratelike *phenotype;
@@ -323,6 +327,7 @@ typedef struct _option
     short treeprint;
   long treeinc;
     boolean usem;
+  boolean recordedusem;
     short migvar;
     boolean plot;
     boolean plotnow;
@@ -1181,6 +1186,7 @@ typedef  struct _proposal_fmt
     xarray_fmt xf;
     MYREAL *mf;
     MYREAL *mt;
+//could be used to calculate p(gn|go):   MYREAL nu;
 #ifdef UEP
 
     ueparray_fmt ut;
