@@ -22,7 +22,7 @@ Copyright 2003-2007 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: random.c 1226 2008-04-02 12:38:07Z beerli $
+$Id: random.c 1230 2008-04-18 13:03:34Z beerli $
 -------------------------------------------------------*/
 /* \file random.c */
 #include "sighandler.h"
@@ -435,7 +435,7 @@ unsigned long int random_seed()
     {
       //#ifndef WINDOWS
       gettimeofday(&tv,0);
-      printf("in random_seed() %li + %li\n",tv.tv_sec,tv.tv_usec);
+      //printf("in random_seed() %li + %li\n",tv.tv_sec,tv.tv_usec);
       seed = tv.tv_sec + tv.tv_usec;
       //#else
       //time(&seed);
