@@ -16,7 +16,7 @@ Copyright 2003-2007 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: reporter.c 1220 2008-03-28 01:36:29Z beerli $
+$Id: reporter.c 1244 2008-05-13 13:42:33Z beerli $
  
 -------------------------------------------------------*/
 /* \file reporter.c 
@@ -354,7 +354,7 @@ void print_param_eff_size(FILE *file, world_fmt *world, long numparam, int offse
   bayes_fmt * bayes = world->bayes;
   char *buffer;
   long start=0;
-
+  //long locus = 1;
   if(!world->options->bayes_infer)
     start=world->numpop2;
 
@@ -400,7 +400,10 @@ void print_param_eff_size(FILE *file, world_fmt *world, long numparam, int offse
 	    }
 	  else
 	    {
-	      pos += sprintf(buffer+pos,"%*.*s%s                  % -5.5f           %10.2f\n", offset, offset, " ", "Rate",autocorr[pa0],effsample[pa0]);
+	      if(world->locus + world->numpop2 == pa0)
+		{
+		  pos += sprintf(buffer+pos,"%*.*s%s_%-5li            % -5.5f           %10.2f\n", offset, offset, " ", "Rate", world->locus, autocorr[pa0],effsample[pa0]);
+		}
 	    }
 	}
     }
@@ -865,9 +868,9 @@ calc_s2 (long tthis, MYREAL *tc, world_fmt * world, long T)
 MYREAL
 calc_s_bayes (long tthis, MYREAL *tc, world_fmt * world)
 {
-  long T            = world->convergence->chain_counts[world->rep];
-  long nn           = 2+world->numpop2 + (world->bayes->mu * world->loci) ;
-  //  long pnum         = world->bayes->numparams;
+  //long T            = world->convergence->chain_counts[world->rep];
+  long nn           = 2+world->numpop2 + (world->bayes->mu) ;
+  long pnum         = world->bayes->numparams;
   
   MYREAL  * params     = world->bayes->params;
   long              i;
@@ -876,13 +879,13 @@ calc_s_bayes (long tthis, MYREAL *tc, world_fmt * world)
   MYREAL            s = 0.0;
 
   i = tthis;
-  for (j = 0; j < T; j++)
+  for (j = 0; j < pnum /*T*/; j++)
     {
       xx = params[j * nn + i] - tc[i];
       s += xx * xx;
     }
   if(s>0.)
-    s /= T - 1.;
+    s /= pnum - 1.;
   return s;
 }
 
@@ -938,11 +941,12 @@ chain_means_ml (MYREAL *thischainmeans, world_fmt * world)
 void
 chain_means_bayes (MYREAL *thischainmeans, world_fmt * world)
 {
-  long              T       = world->convergence->chain_counts[world->rep];
+  //  long              T       = world->convergence->chain_counts[world->rep];
+  long              T       = world->bayes->numparams;
   long              i;
   long              j;
   MYREAL           *params  = world->bayes->params;
-  long              nn      = 2+world->numpop2 + (world->bayes->mu * world->loci) ;
+  long              nn      = 2+world->numpop2 + (world->bayes->mu) ;
 
   for (j = 0; j < T; j++)
     {
@@ -980,7 +984,7 @@ chain_means (MYREAL *thischainmeans, world_fmt * world)
 ///
 /// calculates the average over 
 void 
-chain_s(MYREAL *cs, MYREAL *cm, world_fmt *world, long replicate, long T)
+calc_chain_s(MYREAL *cs, MYREAL *cm, world_fmt *world, long replicate)
 {
   long len;
   long start;
