@@ -16,7 +16,7 @@
  works and are not responsible for any damage you may cause or have.
  
  
- $Id: sequence.c 1157 2008-02-15 21:31:13Z beerli $
+ $Id: sequence.c 1314 2008-07-05 13:47:13Z beerli $
  
 -------------------------------------------------------*/
 /* \file sequence.c
@@ -338,6 +338,13 @@ void
 make_sequences (world_fmt * world, option_fmt * options, data_fmt * data,
                 long locus)
 {
+    if (world->sumtips==0)
+      {
+	data->skiploci[locus] = TRUE;
+        world->data->skiploci[locus] = TRUE;
+        world->skipped += 1;
+      }
+
   makevalues_seq (world, options, data, locus);
   if (options->freqsfrom)
     {
@@ -772,11 +779,16 @@ makevalues_seq (world_fmt * world, option_fmt * options, data_fmt * data,
                             for (b = 0; b < 4; b++)
                                 treenode[i]->x.s[k][l][b] = 1.0;
                             break;
-                            
+#ifdef GAP                            
+                        case '-':
+			  treenode[i]->x.s[k][l][4] = 1.0;
+			  break;
+#else
                         case '-':
                             for (b = 0; b < 4; b++)
                                 treenode[i]->x.s[k][l][b] = 1.0;
                             break;
+#endif
                     }
                 }
             }
@@ -1823,7 +1835,6 @@ snp_invariants (contribarr invariants, world_fmt *world, long locus, phenotype x
     sitelike *val;
     long i, j;
 
-    node *p;
     opt = world->options;
     summ = 0.0;
     /* snp invariants */
