@@ -93,6 +93,113 @@ MYREAL waiting_M(long pop,long to,
     return -9.;
 }
 
+// returns the standard deviation and mean of a autocorrelated sequence
+// using the the autocorrelation to adjust n for the variance
+// where new n = n * (1-r)/(1+r)
+// using one-pass algorithms see also in reporter for my unweighted mathematica
+// function to calculate r. 
+// http://en.wikipedia.org/wiki/Algorithms_for_calculating_variance
+// WEST (1979)
+//n = 0
+//foreach x in the data:
+//if n=0 then 
+//    n = 1
+//    mean = x
+//    S = 0
+//    sumweight = weight
+//  else
+//    n = n + 1
+//    temp = weight + sumweight
+//	S = S + sumweight*weight*(x-mean)^2 / temp
+//	mean = mean + (x-mean)*weight / temp
+//      r = r  + xo xn + mo (n mo  - x1 - xo) - mn ((n + 1) mn - x1 - xn); 
+//    sumweight = temp
+//end if
+//end for
+//    Variance = S * n / ((n-1) * sumweight)  // if sample is the population, omit n/(n-1)
+void weighted_average(float xn, float wn, float *xo, float *wo, 
+		      float *sumweight, float *mn, float *mo, 
+		      float *var, float *n, float *r)
+{
+  float temp;
+  float invtemp;
+  float delta;
+  
+  if(*n<=0)
+    {
+      *n = 1;
+      *mn = xn;
+      *xo = xn;
+      *wo = wn;
+      *mo = xn;
+      *var = 0.;
+      *sumweight = wn;
+      *r = 0.;
+    }
+  else
+    {
+      *n += 1;
+      temp = wn + *sumweight;
+      invtemp = 1. / temp;
+      delta = xn - *mn;
+      *var += *sumweight * wn * delta * delta * invtemp;
+      *mn += delta*wn * invtemp;
+      *r += *sumweight * 0.5 * (wn + *wo) * (xn - *mo) * (*xo - *mo) * invtemp;
+      *sumweight = temp;
+      *xo = xn;
+      *wo = wn;
+      *mo = *mn;
+    }
+}
+
+//n = 0
+//mean = 0
+//M2 = 0
+//foreach x in data:
+//  n = n + 1
+//  delta = x - mean
+//  mean = mean + delta/n
+//    M2 = M2 + delta*(x - mean)      // This expression uses the new value of mean
+//end for
+//variance_n = M2/n
+//    variance = M2/(n - 1)
+void average(float x, float *mean, float *var, float *n)
+{
+  //float temp;
+  //float invtemp;
+  float delta;
+  if(*n<=0)
+    {
+      *n = 1;
+      *mean = x;
+      *var = 0.;
+    }
+  else
+    {
+      *n += 1;
+      delta = x - *mean;
+      *mean += delta / (*n);
+      *var += delta * (x - *mean);
+    }
+}
+
+///
+/// calculates average for value and weight for the skyline bins
+void calc_bin_average(tetra *bin, float val, float weight)
+{
+  float sumweight;
+  // calculates the weighted mean and variance component of the value
+  // the sumweight is not kept but reconstituted from the weight average.
+  sumweight = (*bin)[4] * (*bin)[1]; // average weight * n
+  if((*bin)[0]>0.0 && val > 10. * (*bin)[0]) //Saveguard against outliers, a better method than this?
+    return;
+//syntax:  weighted_average(val, weight, &oldval, &oldweight, &sumweight, &value_mean, &old_mean, &sumweight_mean), &count, &autocorrelation);
+ weighted_average(val, weight, &(*bin)[6], &(*bin)[7], &sumweight, &((*bin)[0]), &(*bin)[8], &((*bin)[2]), &((*bin)[4]), &(*bin)[5]);
+  // calculates the average weight for this bin
+  (*bin)[4] -= 1; // reset for weight average calculation
+  average(weight,  &((*bin)[1]), &((*bin)[3]), &((*bin)[4]));
+}
+
 ///
 /// Calculate the expected parameters given the event
 void calculate_expected_values(tetra **eventbins, 
@@ -113,13 +220,13 @@ void calculate_expected_values(tetra **eventbins,
 
   float lweight;
   //  float unweight;
-  long i;
+  long i,j;
   long pop;
   long diff;
   long allocsize=1;
 
   float val;
-  float se1;
+  // float se1;
   //  float se2;
 
   float weight1 = 0.0F ;
@@ -129,30 +236,14 @@ void calculate_expected_values(tetra **eventbins,
   MYREAL inv_mu_rate = 1./ mu_rate;
   MYREAL inv_eventinterval = 1. / eventinterval;
   long firstbin = (long) ((age - interval) * inv_eventinterval);
+  //long firstbin = (long) (age * inv_eventinterval);
   long bin     = (long) (age * inv_eventinterval);
   float binage  = eventinterval * bin; //this is on the left side of the bin
   MYREAL firstbinage        = eventinterval * firstbin; //this is the age at the left side of first bin
   tetra *bins=NULL;
-
-  // after discussion with Mike P. 09/28/07 DEBUG
-  //if (maxlweight >= world->likelihood[world->G])
-  //  {
-  //    lweight = EXP(world->likelihood[world->G] - maxlweight);
-  //    change = FALSE;
-  //    unweight = 1.0;
-  //  }
-  //else
-  //  {
-  //    oldlweight = maxlweight;
-  //    maxlweight = world->likelihood[world->G]; 
-  //    unweight = EXP( -maxlweight + oldlweight);
-  //    lweight = 1.0;
-  //    change = TRUE;
-  //  }
-  // enable this to disable likelihood weights
   change =FALSE;
   lweight = 1.0;
-  // do we need to report probles when bin number is above 10000?
+  // do we need to report problems when bin number is above 10000?
   // 
   if(age > 1000.0 || bin > 10000)
     return;
@@ -172,18 +263,20 @@ void calculate_expected_values(tetra **eventbins,
       if(val < 0.0)
 	return;
       //      printf("%i> k(k-1)=%li val=%f pop=%li\n",myID,k,val, pop);
-      se1  = val * val;
+      //se1  = val * val;
       //se2  = se1;
     } 
   else
     {
       diff = 0;
       pop = mm2m(from, to, numpop);
-      //val = lineages[to] / interval ;
+
       val = waiting_M(pop, to, world->param0,world->mig0list, lineages,interval, inv_mu_rate, numpop); 
+
+
       if(val < 0.0)
 	return;
-      se1 = val * val;
+      //se1 = val * val;
       //se2 = 1.0;
     }
   if(bin >= eventbinnum[pop])
@@ -192,91 +285,46 @@ void calculate_expected_values(tetra **eventbins,
       eventbins[pop] = myrealloc(eventbins[pop], allocsize * sizeof(tetra));
       for(i=eventbinnum[pop];i < allocsize; i++)
 	{
-	  eventbins[pop][i][0] = 0.;
-	  eventbins[pop][i][1] = 0.;
-	  eventbins[pop][i][2] = 0.;
-	  eventbins[pop][i][3] = 0.;
-	  eventbins[pop][i][4] = 0.;
+	  for(j=0;j<9;j++)
+	    eventbins[pop][i][j] = 0.;
 	}
       eventbinnum[pop] = allocsize;
     }
-
   // weights are the contribution of the estimate to the bin
   if(diff < 0)
       error("time difference is negative -- not possible");
 
-  /*================================ complicated weighting*/
-  //if(change)
-  //  {
-  //    for(p=0; p < world->numpop2; p++)
-  //	{
-  //	  bins = eventbins[p];
-  //	  for(i=0; i < eventbinnum[p]; i++)
-  //	    {
-  //	      if(bins[i][0]>0.0)
-  //		{
-  //		  bins[i][0] *= unweight; 
-  //		  bins[i][1] *= unweight; 
-  //		  bins[i][2] *= unweight; 
-  //		  bins[i][3] *= unweight; 
-  //		}
-  //	    }
-  //	}
-  //  }
   bins = eventbins[pop];
+
   switch(diff)
     {
       //start and stop bin are the same the whole interval does not extend over bin boundaries
     case 0: 
       weight1 = interval * inv_eventinterval; // or =lweight=1.0
-      bins[bin][0] +=  val * weight1; // parameter of interest
-      bins[bin][1] += weight1;        // its weight per bin
-      bins[bin][2] += se1 * weight1;  // std of parameter 
-      bins[bin][3] += weight1 * weight1; // std of weight
-      bins[bin][4] += 1.0;
+      calc_bin_average(&bins[bin], val, weight1);
       break;
-      // the interval crosses a single bin boundary
     case 1: 
+      // the interval crosses a single bin boundary
       // older bin
       weight1 = (age - binage) * inv_eventinterval; 
-      bins[bin][0] +=  val * weight1;
-      bins[bin][1] += weight1;
-      bins[bin][2] += se1 * weight1;
-      bins[bin][3] += weight1 * weight1;
-      bins[bin][4] += 1.0;
+      calc_bin_average(&bins[bin], val, weight1);
       // newer bin
-      weight2 = (binage - age + interval) * inv_eventinterval; 
-      bins[firstbin][0] +=  val * weight2;
-      bins[firstbin][1] += weight2;
-      bins[firstbin][2] += se1 * weight2;
-      bins[firstbin][3] += weight2 * weight2;
-      bins[firstbin][4] += 1.0;
+      calc_bin_average(&bins[bin], val, weight2);
       break;
-      // start and stop are in different bins and more than one boundary apart
     default:
-      //this is old [081406] weight1 = (age-interval+firstbinage+eventinterval) * inv_eventinterval;
+      // start and stop are in different bins and more than one boundary apart
       weight1 = (-age + interval + firstbinage + eventinterval) * inv_eventinterval;
-      bins[firstbin][0] +=  val * weight1;
-      bins[firstbin][1] += weight1;
-      bins[firstbin][2] += se1 * weight1;
-      bins[firstbin][3] += weight1 * weight1;
-      bins[firstbin][4] += 1.0;
+      calc_bin_average(&bins[bin], val, weight1);
       for(i=firstbin+1; i < bin; i++)
 	{
-	  bins[i][0] += val;
-	  bins[i][1] += lweight; // = 1.0
-	  bins[i][2] += se1;
-	  bins[i][3] += lweight * lweight; /* 1 x 1*/
-	  bins[i][4] += 1.0;
+	  calc_bin_average(&bins[bin], val, 1.0);
 	}
-      weight2 = (age - binage) * inv_eventinterval; 
-      bins[bin][0] += weight2 * val;
-      bins[bin][1] += weight2;
-      bins[bin][2] += se1 * weight2;
-      bins[bin][3] += weight2 * weight2;
-      bins[bin][4] += 1.0;
+      weight2 = (age - binage) * inv_eventinterval;
+    calc_bin_average(&bins[bin], val, weight2);
     }
   //  printf("@%c %li %li :%li:  %f %f %f %f %f %f %f\n", from==to ? 'c' : 'm', from, to, bin, val, age, bins[bin][0],bins[bin][1], lweight, weight1, weight2); 
+  //  if(pop==0 && bin==15)
+  //  printf("@ %li %li | %f | %f %f %f\n",pop, bin, val, bins[bin][0], bins[bin][2] / ((bins[bin][4]*((1.- bins[bin][5])/(1.+ bins[bin][5]))-1.) * bins[bin][1]),bins[bin][5]/bins[bin][2]);
 }
 
 
@@ -286,7 +334,7 @@ void calculate_expected_values(tetra **eventbins,
 void
 setup_expected_events (world_fmt * world, option_fmt * options)
 {
-    long locus, i, j;
+  long locus, i, j,z;
     long allocsize = 1;
     MYREAL  binsize = world->options->eventbinsize; // in mutational units (=time scale)
     if (world->options->mighist && world->options->skyline)
@@ -302,11 +350,8 @@ setup_expected_events (world_fmt * world, option_fmt * options)
 	      world->mighistloci[locus].eventbins[i] = (tetra *) mycalloc (allocsize, sizeof (tetra));
 	      for(j=0;j<allocsize;j++)
 		{
-		  world->mighistloci[locus].eventbins[i][j][0] = 0.;
-		  world->mighistloci[locus].eventbins[i][j][1] = 0.;
-		  world->mighistloci[locus].eventbins[i][j][2] = 0.;
-		  world->mighistloci[locus].eventbins[i][j][3] = 0.;
-		  world->mighistloci[locus].eventbins[i][j][4] = 0.;
+		  for(z=0;z<9;z++)
+		    world->mighistloci[locus].eventbins[i][j][z] = 0.;
 		}
             }
         }
@@ -407,7 +452,7 @@ void print_expected_values_tofile(FILE *file,  world_fmt *world)
     }
   fprintf(file,"#\n#----------------------------------------------------------------------------\n");
   fprintf(file,"# Locus Parameter-number Bin Age Parameter-value Parameter-Frequency \n");
-  fprintf(file,"#        Standard-deviation Counts-per-bin\n");
+  fprintf(file,"#        Standard-deviation Counts-per-bin Autocorrelation-per-bin\n");
   fprintf(file,"#----------------------------------------------------------------------------\n");
   fprintf(file,"# (*) values with -1 were NEVER visited\n");
   if(world->loci>1)
@@ -432,8 +477,8 @@ void print_expected_values_tofile(FILE *file,  world_fmt *world)
 	      age = eventbinsize / 2.;
 	      for(i = 0; i < eventbinnum[pop]; i++)
 		{
-		  fprintf(file,"%li %li %li %10.10f %10.10f %10.10f %10.10f %10.0f\n", 
-			  locus+1, pop+1, i+1, age, eventbins[pop][i][0], eventbins[pop][i][1],eventbins[pop][i][2],eventbins[pop][i][4]);
+		  fprintf(file,"%li %li %li %10.10f %10.10f %10.10f %10.10f %10.10f %10.10f\n", 
+			  locus+1, pop+1, i+1, age, eventbins[pop][i][0], eventbins[pop][i][1],eventbins[pop][i][2],eventbins[pop][i][4],eventbins[pop][i][5]);
 		  age += eventbinsize;
 		}
 	    } 
@@ -454,7 +499,8 @@ void prepare_expected_values(world_fmt *world)
   long eventbinnum_allmax=0;
   float * suml;
   float *count;
-  float weight_average;
+  float rs;
+
   suml = (float *) mycalloc(world->numpop2,sizeof(float));
   count = (float *) mycalloc(world->numpop2,sizeof(float));
 
@@ -480,31 +526,40 @@ void prepare_expected_values(world_fmt *world)
 		      eventbins[pop][i][2] = 0.0;
 		      eventbins[pop][i][3] = 0.0;
 		      eventbins[pop][i][4] = 0.0;
+		      eventbins[pop][i][5] = 0.0;
+		      eventbins[pop][i][6] = 0.0;
+		      eventbins[pop][i][7] = 0.0;
+		      eventbins[pop][i][8] = 0.0;
 		    }
-		  else
-		    {
-		      eventbins[pop][i][0] /= eventbins[pop][i][1]; //average: sum(val * weight)/sum(weight)
-		      // balancing the weights sum(val^2 weights)/ sum(weights)
-		      eventbins[pop][i][2] /= eventbins[pop][i][1]; // ---> val^2
-		      // Sum(val^2) - (E(val)^2)
-		      eventbins[pop][i][2] -= (eventbins[pop][i][0] * eventbins[pop][i][0]);
-		      // 1/n (sqrt(var)
-		      //  eventbins[pop][i][2] = sqrt(fabs(eventbins[pop][i][2])/(eventbins[pop][i][4]-1.));
-		      eventbins[pop][i][2] = sqrt(fabs(eventbins[pop][i][2]));
-		      //		  eventbins[pop][i][3] = eventbins[pop][i][1];
-		    }		  
 		  sum += eventbins[pop][i][1];
 		}
 	      for(i = 0; i < eventbinnum[pop]; i++)
 		{
 		  if(eventbins[pop][i][1] <= 0.0)
 		    continue;
+		  // calculate standard deviations of values (using weighted formula)
+		  // and adjusting for correlated samples
+		  eventbins[pop][i][5] /= eventbins[pop][i][2];//calculation of autocorrelation coefficient
+		  rs = eventbins[pop][i][5];
+		  rs = eventbins[pop][i][4] * (1.-rs)/(1.+rs); 
+		  eventbins[pop][i][2] *= 1./((rs-1.) * eventbins[pop][i][1]);
+		  if (MYISNAN (eventbins[pop][i][5]))
+		    {
+		      eventbins[pop][i][5] = -999.;
+		    }
+		  if (eventbins[pop][i][2]<0. || MYISNAN (eventbins[pop][i][2]))
+		    {
+		      eventbins[pop][i][2]=-999.;
+		      //warning("%i> the Variance for parameter %li in the skyline plots was negative -- this should not happen!",myID,i);
+		    }
+		  else
+		    {
+		      eventbins[pop][i][2] = sqrt(eventbins[pop][i][2]);
+		    }
+		  // calculate standard deviations of weights (this were unweighted)
+		  eventbins[pop][i][3] *= eventbins[pop][i][4]/(eventbins[pop][i][4]-1.); 
+		  eventbins[pop][i][3] = sqrt(eventbins[pop][i][3]);
 		  eventbins[pop][i][1] /= sum; // calculate frequency: sum(weight_i)/sum(sum(weight_i)_j)
-		  // sum(weight)/counts
-		  weight_average = eventbins[pop][i][1] / eventbins[pop][i][4];
-		  // sum(weight^2) - waverage^2
-		  eventbins[pop][i][3] -= weight_average * weight_average;
-		  eventbins[pop][i][3] = sqrt(fabs(eventbins[pop][i][3]/(eventbins[pop][i][4]-1.)));
 		}
 	    } 
 	}
@@ -539,6 +594,7 @@ void prepare_expected_values(world_fmt *world)
 			  eventbins_all[pop][i][2] += eventbins[pop][i][2] * eventbins[pop][i][1];
 			  eventbins_all[pop][i][3] += eventbins[pop][i][3] * eventbins[pop][i][1];
 			  eventbins_all[pop][i][4] += eventbins[pop][i][4];
+			  eventbins_all[pop][i][5] += eventbins[pop][i][5] * eventbins[pop][i][1];
 			}
 		      suml[pop] += eventbins[pop][i][1];
 		      count[pop] += eventbins[pop][i][4];
@@ -555,13 +611,10 @@ void prepare_expected_values(world_fmt *world)
 		  eventbins_all[pop][i][0] /= eventbins_all[pop][i][1];//average
 		  eventbins_all[pop][i][2] /= eventbins_all[pop][i][1];//average standard deviation
 		  eventbins_all[pop][i][3] /= eventbins_all[pop][i][1];//average weight
-		      //eventbins_all[pop][i][0] /= suml[pop];
-		      //eventbins_all[pop][i][1] /= suml[pop];
-		      //eventbins_all[pop][i][2] /= suml[pop];
-		  eventbins_all[pop][i][4] /= count[pop];
+		  eventbins_all[pop][i][4] /= world->loci;//average count:count[pop];
+		  eventbins_all[pop][i][5] /= eventbins_all[pop][i][1];//average autocorrelation coefficient
 		}
 	    }
-	  //     eventbins_all[pop][i][0] /= suml[pop];
 	}  
     } 
   myfree(suml);
@@ -649,3 +702,4 @@ void debug_skyline(world_fmt *world, char text[])
     }
   fprintf(file,"#%i >>>>>>>>>>>>>>> %s <<<<<<<<<<<<<<<<<END\n",myID,text);
 }
+
