@@ -8,7 +8,7 @@ using a Metropolis-Hastings Monte Carlo algorithm
     Peter Beerli 2006, Tallahassee
     beerli@scs.fsu.edu
 
-    Copyright 2006 Peter Beerli, Tallahassee
+    Copyright 2006-8 Peter Beerli, Tallahassee
 
     This software is distributed free of charge for non-commercial use
     and is copyrighted. Of course, we do not guarantee that the software
@@ -175,7 +175,7 @@ MYREAL slice (MYREAL *startval, long which, world_fmt * world, MYREAL  (*func) (
   priorratio = func(ezr, -1. , bayes, w);
   set_slice_param(ezr,which, world);
   fzr= probg_treetimes(world) + priorratio;
-  while(y < fzl)
+  while(y < fzl && y > -DBL_MAX)
     {
       zl -= stick;
       ezl = EXP(zl);
@@ -183,7 +183,7 @@ MYREAL slice (MYREAL *startval, long which, world_fmt * world, MYREAL  (*func) (
       set_slice_param(ezl,which, world);
       fzl= probg_treetimes(world) + priorratio;
     }
-  while(y < fzr)
+  while(y < fzr && y > -DBL_MAX)
     {
       zr += stick;
       ezr = EXP(zr);
