@@ -20,7 +20,7 @@ Copyright 2003-2006 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: tools.c 1172 2008-02-19 20:12:21Z beerli $
+$Id: tools.c 1243 2008-05-10 18:07:45Z beerli $
 -------------------------------------------------------*/
 /* \file tools.c */
 
@@ -619,7 +619,10 @@ init_files (world_fmt * world, data_fmt * data, option_fmt * options)
 				openfile (&data->sumfile, options->sumfilename, "w+",  NULL);
 		}
 		else
-			openfile (&data->sumfile, options->sumfilename, "r+",  NULL);
+		  {
+		    if(!options->bayes_infer)
+		      openfile (&data->sumfile, options->sumfilename, "r+",  NULL);
+		  }
 
 		openfile (&world->outfile, options->outfilename, "w+",  NULL);
 #ifdef MPI
@@ -693,7 +696,12 @@ init_files (world_fmt * world, data_fmt * data, option_fmt * options)
 	    if(options->has_bayesfile)
 	      openfile (&world->bayesfile, options->bayesfilename, "w+",  NULL);
 	    if(options->has_bayesmdimfile)
-	      openfile (&world->bayesmdimfile, options->bayesmdimfilename, "w+",  NULL);
+	      {
+		if(options->datatype != 'g')
+		  openfile (&world->bayesmdimfile, options->bayesmdimfilename, "w+",  NULL);
+		else
+		  openfile(&world->bayesmdimfile, options->bayesmdimfilename,"r+",NULL);
+	      }
 #ifdef MPI
 	    if(options->has_bayesfile)
 	      setup_filehandle_db((void *) world->bayesfile, world, options,data);
