@@ -14,7 +14,7 @@ Copyright 2002 Peter Beerli and Joseph Felsenstein
         and is copyrighted. Of course, we do not guarantee that the software
         works and are not responsible for any damage you may cause or have.
  
-$Id: uep.c 514 2006-11-09 20:14:08Z beerli $
+$Id: uep.c 886 2007-08-18 03:09:50Z beerli $
 */
 /* \file uep.c 
 Unique event polymorphism manipulation
@@ -70,10 +70,10 @@ setup_uep (world_fmt * world, option_fmt * options)
 }
 
 void
-destroy_uep (world_fmt * world)
+destroy_uep (world_fmt * world, long storesize)
 {
     long loci = world->loci;
-  long locus;
+    long locus;
     long i;
     long j;
   if (world->options->uep)
@@ -86,11 +86,11 @@ destroy_uep (world_fmt * world)
 	{
 	  for (i = 0; i < storesize; ++i)
 	    {
-	      for (j = 0; j < size; ++j)
+	      for (j = 0; j < world->options->lsteps; ++j)
 		{
 		  myfree(world->ueplikestore[locus][i][j]);
-		  myfree(world->ueptimestore[j].populations);
-		  myfree(world->ueptimestore[j].ueptime);
+		  myfree(world->ueptime[j].populations);
+		  myfree(world->ueptime[j].ueptime);
 		}
 	      myfree(world->ueplikestore[locus][i]);
 	      myfree(world->ueptimestore[locus][i]);
@@ -103,7 +103,7 @@ destroy_uep (world_fmt * world)
       myfree(world->ueplikestore);
       myfree(world->ueptimestore);
       myfree(world->ueprootstore);
-      for (j = 0; j < size; ++j)
+      for (j = 0; j < world->options->lsteps; ++j)
 	{
 	  myfree(world->ueptime[j].populations);
 	  myfree(world->ueptime[j].ueptime);
@@ -121,7 +121,7 @@ pseudonu_twostate (proposal_fmt * proposal,
     //  static long count=0;
     long j;
     MYREAL pija11, pija12, pija21, pija22;
-    //  MYREAL x3m = -DBL_MAX;
+    //  MYREAL x3m = -MYREAL_MAX;
     MYREAL r = proposal->world->options->uepmu;
     MYREAL s = proposal->world->options->uepnu;
     MYREAL rs = r + s;
@@ -167,7 +167,7 @@ twostate_nuview (node * mother, world_fmt * world, const long locus)
     MYREAL v1, v2;
     MYREAL pija11, pija12, pija21, pija22;
     pair *xx1, *xx2;
-    //  MYREAL x3m = -DBL_MAX;
+    //  MYREAL x3m = -MYREAL_MAX;
     pair *xx3;
     MYREAL r = world->options->uepmu;
     MYREAL s = world->options->uepnu;
@@ -1428,7 +1428,7 @@ pseudo_ueplikelihood (world_fmt * world, proposal_fmt * proposal)
             }
         }
     }
-    return -DBL_MAX;  //never come here
+    return -MYREAL_MAX;  //never come here
 }
 
 MYREAL
